@@ -8,8 +8,8 @@ from ._notebook import Notebook
 
 
 def nbproject_id():  # rename to nbproject_id also in metadata slot?
-    """An 8-byte ID encoded as a 12-character base62 string."""
-    # https://github.com/laminlabs/notes/blob/main/2022-04-04-human-friendly-ids.ipynb
+    """A 12-character base62 string."""
+    # https://github.com/laminlabs/lamin-notes/blob/main/docs/2022/ids.ipynb
     base62 = string.digits + string.ascii_letters.swapcase()
     id = "".join(secrets.choice(base62) for i in range(12))
     return id
